==> 0.0.56.tar.gz: lib/widget/dialog/custom_dialog_permission.dart <==

import '../../common/values/sizes.dart';
import 'package:easy_localization/src/public_ext.dart';
import 'package:flutter/material.dart';
import 'package:permission_handler/permission_handler.dart';

import '../custom/custom_icon.dart';

class CustomDialogPermission extends StatefulWidget {
  @override
  _CustomDialogPermissionState createState() => _CustomDialogPermissionState();
}

class _CustomDialogPermissionState extends State<CustomDialogPermission> {
  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: () async => false,
      child: Center(
        child: Padding(
          padding: const EdgeInsets.symmetric(horizontal: 12.0),
          child: SizedBox(
            height: Sizes.HEIGHT_250,
            width: MediaQuery.of(context).size.width,
            child: Card(
              shape: RoundedRectangleBorder(
                borderRadius: BorderRadius.all(Radius.circular(10.0)),
              ),
              color: Colors.white,
              child: Padding(
                padding: const EdgeInsets.symmetric(vertical: 20.0),
                child: Column(
                  mainAxisSize: MainAxisSize.max,
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: <Widget>[
                    Text(
                      "text_access_permission".tr(),
                      style: TextStyle(
                        color: Colors.green,
                        fontSize: Sizes.TEXT_SIZE_22,
                        fontWeight: FontWeight.bold,
                      ),
                    ),
                    CustomIcon(
                      icon: Icons.app_settings_alt,
                      size: 60.0,
                      color: Colors.red,
                    ),
                    Row(
                      mainAxisSize: MainAxisSize.max,
                      mainAxisAlignment: MainAxisAlignment.spaceAround,
                      children: <Widget>[
                        ElevatedButton.icon(
                          onPressed: () => _closePopup(),
                          icon: Icon(Icons.cancel),
                          label: Text('Cancel'),
                        ),
                        ElevatedButton.icon(
                          onPressed: () => _openPermissionSettings(),
                          icon: Icon(Icons.arrow_forward_ios),
                          label: Text('Go To Settings'),
                        ),
                      ],
                    ),
                  ],
                ),
              ),
            ),
          ),
        ),
      ),
    );
  }

  _openPermissionSettings() async {
    await openAppSettings();
    _closePopup();
  }

  _closePopup() {
    Navigator.of(context).pop();
  }
}

==> 0.0.63.tar.gz: lib/widget/dialog/custom_dialog_permission.dart <==

import '../../common/values/sizes.dart';
import 'package:easy_localization/src/public_ext.dart';
import 'package:flutter/material.dart';
import 'package:permission_handler/permission_handler.dart';

import '../custom/custom_icon.dart';

class CustomDialogPermission extends StatefulWidget {
  @override
  _CustomDialogPermissionState createState() => _CustomDialogPermissionState();
}

class _CustomDialogPermissionState extends State<CustomDialogPermission> {
  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: () async => false,
      child: Center(
        child: Padding(
          padding: EdgeInsets.symmetric(horizontal: Sizes.PADDING_12),
          child: SizedBox(
            height: Sizes.HEIGHT_250,
            width: MediaQuery.of(context).size.width,
            child: Card(
              shape: RoundedRectangleBorder(
                borderRadius: BorderRadius.all(Radius.circular(Sizes.RADIUS_10)),
              ),
              color: Colors.white,
              child: Padding(
                padding: EdgeInsets.symmetric(vertical: Sizes.PADDING_20),
                child: Column(
                  mainAxisSize: MainAxisSize.max,
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: <Widget>[
                    Text(
                      "text_access_permission".tr(),
                      style: TextStyle(
                        color: Colors.green,
                        fontSize: Sizes.TEXT_SIZE_22,
                        fontWeight: FontWeight.bold,
                      ),
                    ),
                    CustomIcon(
                      icon: Icons.app_settings_alt,
                      size: 60.0,
                      color: Colors.red,
                    ),
                    Row(
                      mainAxisSize: MainAxisSize.max,
                      mainAxisAlignment: MainAxisAlignment.spaceAround,
                      children: <Widget>[
                        ElevatedButton.icon(
                          onPressed: () => _closePopup(),
                          icon: Icon(Icons.cancel),
                          label: Text('Cancel'),
                        ),
                        ElevatedButton.icon(
                          onPressed: () => _openPermissionSettings(),
                          icon: Icon(Icons.arrow_forward_ios),
                          label: Text('Go To Settings'),
                        ),
                      ],
                    ),
                  ],
                ),
              ),
            ),
          ),
        ),
      ),
    );
  }

  _openPermissionSettings() async {
    await openAppSettings();
    _closePopup();
  }

  _closePopup() {
    Navigator.of(context).pop();
  }
}
